Documentation
¶
Index ¶
- Variables
- func GetForms(id uint8, ids ...uint8) (f map[uint8]Form)
- type Field
- func (f *Field) Bytes() (o []byte)
- func (f *Field) Checked() (o bool)
- func (f *Field) Float32() (o float32)
- func (f *Field) Float64() (o float64)
- func (f *Field) Str() (o string)
- func (f *Field) Strs() (o []string)
- func (f *Field) Time() (o time.Time)
- func (f *Field) Uint() (o uint)
- func (f *Field) Uint8() (o uint8)
- func (f *Field) Uint8s() (o []uint8)
- func (f *Field) Uint16() (o uint16)
- func (f *Field) Uint16s() (o []uint16)
- func (f *Field) Uint32() (o uint32)
- func (f *Field) Uint32s() (o []uint32)
- func (f *Field) Uint64() (o uint64)
- func (f *Field) Uint64s() (o []uint64)
- func (f *Field) Uints() (o []uint)
- type Form
- type Option
Constants ¶
This section is empty.
Variables ¶
var GetFields func(uint8) []Field
GetFields defines a function signature to retrieve a form's fields, instead of passing function definitions, pointers or interfaces between packages. BuildIt.ninja can generate this code when using the Forms feature. GetFields is used by session.
Functions ¶
Types ¶
type Field ¶
type Field struct {
Name, Err, Placeholder string
Options []Option
Max, Min interface{}
MaxLen, MinLen int
Step float32
Regex *regexp.Regexp
V8 func(*Field, ...string)
Value interface{}
Required, Disable, Focus bool
}
Field represents attributes for each HTML form field.
Click to show internal directories.
Click to hide internal directories.